@@ -25,9 +25,10 @@
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Boolean.h>
 
-#include "Sudoku.h"
+#include "GameModel.h"
 
-class GameArea : public Lum::Object
+
+class GameArea : public Lum::Control
 {
 private:
   Lum::OS::FontRef       minFont;
@@ -41,19 +42,13 @@ private:
   Lum::OS::ColorRef      hintColor;
   size_t                 boxSize;
   size_t                 size;
-  Sudoku                 game;
-  Sudoku                 riddle;
-  Sudoku                 solution;
-  size_t                 marks[Sudoku::size];
-  size_t                 focusedCell;
 
-  Lum::Model::ActionRef  focusChangedAction;
   Lum::Model::BooleanRef hintMode;
-  Lum::Model::BooleanRef finished;
+
+  GameModelRef           model;
 
 private:
-  int GetCellOffset( size_t index) const;
-  void SetFinished(bool finished);
+  int GetCellOffset(size_t index) const;
 
 public:
   GameArea();
@@ -61,14 +56,7 @@ public:
   bool HandlesClickFocus() const;
   bool HandlesKeyFocus() const;
 
-  void SetModel(const Sudoku &riddle, const Sudoku &solution);
-
-  void SetGame(const Game& game);
-
-  void GetGame(Game& game) const;
-  void GetGame(Sudoku& game) const;
-  void GetRiddle(Sudoku& riddle) const;
-  void GetSolution(Sudoku& solution) const;
+  bool SetModel(Lum::Base::Model* model);
 
   void CalcSize();
   void Layout();
@@ -82,20 +70,8 @@ public:
   bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
   bool HandleKeyEvent(const Lum::OS::KeyEvent& event);
 
-  Lum::Model::Action* GetFocusChangedAction() const;
-  Lum::Model::Boolean* GetFinishedModel() const;
   Lum::Model::Boolean* GetHintMode() const;
 
-  bool IsFocusedCellEditable() const;
-  bool IsCellInMarkModus() const;
-  size_t GetFocusedCellValue() const;
-  size_t GetFocusedCellMarks() const;
-  void SetFocusedCellValue(size_t value);
-  void SetFocusedCellMarks(size_t value);
-  void MarkEmpty();
-
-  void Solve();
-
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
 };
 
